@@ -443,7 +443,7 @@ class TagTest(base.EC2TestCase):
     @decorators.idempotent_id('07b2f20d-6b26-4c3d-9d32-93f98f187d78')
     def test_tag_customer_gateway(self):
         data = self.client.create_customer_gateway(
-            Type='ipsec.1', PublicIp='198.51.100.77', BgpAsn=65000)
+            Type='ipsec.1', IpAddress='198.51.100.77', BgpAsn=65000)
         cgw_id = data['CustomerGateway']['CustomerGatewayId']
         self.addResourceCleanUp(self.client.delete_customer_gateway,
                                 CustomerGatewayId=cgw_id)
@@ -458,7 +458,7 @@ class TagTest(base.EC2TestCase):
 
     @testtools.skip("Some unknown bug. Will fix this later")
     @base.skip_without_vpc()
-    @base.skip_without_network_feature('vpnaas')
+    @base.skip_without_vpnaas_enabled()
     @decorators.idempotent_id('a0437171-81a1-4871-9b71-c7629b25c337')
     def test_tag_vpn_gateway(self):
         data = self.client.create_vpn_gateway(Type='ipsec.1')
@@ -476,7 +476,7 @@ class TagTest(base.EC2TestCase):
 
     @testtools.skip("Some unknown bug. Will fix this later")
     @base.skip_without_vpc()
-    @base.skip_without_network_feature('vpnaas')
+    @base.skip_without_vpnaas_enabled()
     @decorators.idempotent_id('ecd343b4-f448-4990-880d-02a68febc9cf')
     def test_tag_vpn_connection(self):
         data = self.client.create_customer_gateway(
