@@ -241,22 +241,18 @@ def skip_without_vpc(*args, **kwargs):
     return decorator
 
 
-def check_network_feature_enabled(ext_name):
-    if hasattr(CONF, 'network_feature_enabled'):
-        ext_list = CONF.network_feature_enabled.api_extensions
-    else:
-        ext_list = ['all']
-    if 'all' not in ext_list and ext_name not in ext_list:
-        msg = ("Skipped network test as %s is not available" % ext_name)
+def check_vpnaas_enabled():
+    if not CONF.aws.vpnaas_enabled:
+        msg = ("Skipped VPN test as vpnaas is not available")
         raise testtools.TestCase.skipException(msg)
 
 
-def skip_without_network_feature(ext_name, *args, **kwargs):
+def skip_without_vpnaas_enabled(*args, **kwargs):
     """A decorator useful to skip tests without specified network extension."""
     def decorator(f):
         @functools.wraps(f)
         def wrapper(self, *func_args, **func_kwargs):
-            check_network_feature_enabled(ext_name)
+            check_vpnaas_enabled()
             return f(self, *func_args, **func_kwargs)
         return wrapper
     return decorator
@@ -438,7 +434,7 @@ class EC2TestCase(base.BaseTestCase):
                     obj_id = obj_id(kw_args)
                     try:
                         waiter().wait_delete(obj_id)
-                    except botocore.exceptions.ClientError as e:
+                    except botocore.exceptions.ClientError:
                         LOG.exception('Exception occurred in cleanup waiting')
                         return False
             except botocore.exceptions.ClientError as e:
